@@ -27,9 +27,13 @@ typedef struct im_ibus
 
 	mkf_parser_t *  parser_ibus ;	/* for ibus encoding  */
 
-	/* Not used for now */
-	u_int  pressing_mod_key ;
-	u_int  mod_ignore_mask ;
+	/*
+	 * Cache a result of ibus_input_context_is_enabled() which uses
+	 * DBus connection internally.
+	 */
+	gboolean  is_enabled ;
+
+	XKeyEvent  prev_key ;
 
 }  im_ibus_t ;
 
@@ -43,7 +47,9 @@ static KIK_LIST( im_ibus_t)  ibus_list = NULL ;
 
 static int  ref_count = 0 ;
 static x_im_export_syms_t *  syms = NULL ; /* mlterm internal symbols */
+#ifdef  DEBUG_MODKEY
 static int  mod_key_debug = 0 ;
+#endif
 
 
 /* --- static functions --- */
@@ -108,7 +114,7 @@ update_preedit_text(
 	mkf_char_t  ch ;
 
 	ibus = (im_ibus_t*) data ;
-	
+
 	if( ( len = ibus_text_get_length( text)) > 0)
 	{
 		u_int  index ;
@@ -309,6 +315,26 @@ commit_text(
 	(*conv->delete)( conv) ;
 }
 
+static void
+forward_key_event(
+	IBusInputContext *  context ,
+	guint  keyval ,
+	guint  keycode ,
+	guint  state ,
+	gpointer  data
+	)
+{
+	im_ibus_t *  ibus ;
+
+	ibus = (im_ibus_t*) data ;
+
+	if( ibus->prev_key.keycode == keycode + 8)
+	{
+		ibus->prev_key.state |= IBUS_IGNORED_MASK ;
+		XPutBackEvent( ibus->prev_key.display , &ibus->prev_key) ;
+		memset( &ibus->prev_key , 0 , sizeof(XKeyEvent)) ;
+	}
+}
 
 /*
  * methods of x_im_t
@@ -328,7 +354,11 @@ delete(
 		(*ibus->parser_ibus->delete)( ibus->parser_ibus) ;
 	}
 
+#ifdef  DBUS_H
 	ibus_object_destroy( (IBusObject*)ibus->context) ;
+#else
+	ibus_proxy_destroy( (IBusProxy*)ibus->context) ;
+#endif
 
 	ref_count -- ;
 
@@ -344,11 +374,18 @@ delete(
 	{
 		int  fd ;
 
+	#ifdef  DBUS_H
 		if( dbus_connection_get_unix_fd( ibus_connection_get_connection(
 				ibus_bus_get_connection( ibus_bus)) , &fd))
+	#else
+		if( ( fd = g_socket_get_fd( g_socket_connection_get_socket(
+				g_dbus_connection_get_stream(
+					ibus_bus_get_connection( ibus_bus))))) != -1)
+	#endif
 		{
 			(*syms->x_term_manager_remove_fd)( fd) ;
 		}
+
 		(*syms->x_term_manager_remove_fd)( IBUS_ID) ;
 
 		ibus_object_destroy( (IBusObject*)ibus_bus) ;
@@ -377,29 +414,51 @@ key_event(
 	)
 {
 	im_ibus_t *  ibus ;
-	int  is_enabled ;
 
 	ibus = (im_ibus_t*) im ;
 
-	is_enabled = ibus_input_context_is_enabled( ibus->context) ;
-
-	if( ibus_input_context_process_key_event( ibus->context , ksym , event->keycode - 8 ,
+	if( event->state & IBUS_IGNORED_MASK)
+	{
+		/* Is put back in forward_key_event */
+		event->state &= ~IBUS_IGNORED_MASK ;
+	}
+	else if( ibus_input_context_process_key_event( ibus->context , ksym , event->keycode - 8 ,
 			event->state | (event->type == KeyRelease ? IBUS_RELEASE_MASK : 0)))
 	{
-		if( is_enabled != ibus_input_context_is_enabled( ibus->context) ||
-		   (ibus_input_context_is_enabled( ibus->context) &&
-		    (ibus->im.preedit.filled_len > 0 || key_char > 0x20)))
+		gboolean  is_enabled_old ;
+
+		is_enabled_old = ibus->is_enabled ;
+		ibus->is_enabled = ibus_input_context_is_enabled( ibus->context) ;
+
+		if( ibus->is_enabled != is_enabled_old)
 		{
 			return  0 ;
 		}
-		else
+		else if( ibus->is_enabled)
 		{
-			/*
-			 * Even if input context is enabled, enter, backspace, space etc
-			 * keys are avaiable as far as no characters are input.
-			 */
+		#ifndef  DBUS_H
+		#if  0
+			g_dbus_connection_flush_sync( ibus_bus_get_connection( ibus_bus) ,
+				NULL , NULL) ;
+		#endif
+			g_main_context_iteration( g_main_context_default() , FALSE) ;
+		#endif
+
+			memcpy( &ibus->prev_key , event , sizeof(XKeyEvent)) ;
+
+			return  0 ;
 		}
 	}
+	else if( ibus->im.preedit.filled_len > 0)
+	{
+		/* Pressing "q" in preediting. */
+	#ifndef  DBUS_H
+	#if  0
+		g_dbus_connection_flush_sync( ibus_bus_get_connection( ibus_bus) , NULL , NULL) ;
+	#endif
+		g_main_context_iteration( g_main_context_default() , FALSE) ;
+	#endif
+	}
 
 	return  1 ;
 }
@@ -413,13 +472,15 @@ switch_mode(
 
 	ibus =  (im_ibus_t*)  im ;
 
-	if( ibus_input_context_is_enabled( ibus->context))
+	if( ibus->is_enabled)
 	{
 		ibus_input_context_disable( ibus->context) ;
+		ibus->is_enabled = FALSE ;
 	}
 	else
 	{
 		ibus_input_context_enable( ibus->context) ;
+		ibus->is_enabled = TRUE ;
 	}
 	
 	return  1 ;
@@ -430,7 +491,7 @@ is_active(
 	x_im_t *  im
 	)
 {
-	return  ibus_input_context_is_enabled( ((im_ibus_t*)im)->context) ;
+	return  ((im_ibus_t*)im)->is_enabled ;
 }
 
 static void
@@ -448,8 +509,6 @@ focused(
 	{
 		(*ibus->im.cand_screen->show)( ibus->im.cand_screen) ;
 	}
-
-	ibus->pressing_mod_key = 0 ;
 }
 
 static void
@@ -467,33 +526,26 @@ unfocused(
 	{
 		(*ibus->im.cand_screen->hide)( ibus->im.cand_screen) ;
 	}
-
-	ibus->pressing_mod_key = 0 ;
 }
 
 
-static void
-connection_handler_idling(void)
-{
-	DBusConnection *  connection ;
-
-	connection = ibus_connection_get_connection( ibus_bus_get_connection( ibus_bus)) ;
-
-	dbus_connection_read_write( connection , 0) ;
-
-	while( ! dbus_connection_dispatch( connection)) ;
-}
-
 static void
 connection_handler(void)
 {
+#ifdef  DBUS_H
 	DBusConnection *  connection ;
 
 	connection = ibus_connection_get_connection( ibus_bus_get_connection( ibus_bus)) ;
 
 	dbus_connection_read_write( connection , 0) ;
 
-	while( ! dbus_connection_dispatch( connection)) ;
+	while( dbus_connection_dispatch( connection) == DBUS_DISPATCH_DATA_REMAINS) ;
+#else
+#if  0
+	g_dbus_connection_flush_sync( ibus_bus_get_connection( ibus_bus) , NULL , NULL) ;
+#endif
+	g_main_context_iteration( g_main_context_default() , FALSE) ;
+#endif
 }
 
 
@@ -505,7 +557,7 @@ im_ibus_new(
 	ml_char_encoding_t  term_encoding ,
 	x_im_export_syms_t *  export_syms ,
 	char *  engine ,
-	u_int  mod_ignore_mask
+	u_int  mod_ignore_mask		/* Not used for now. */
 	)
 {
 	im_ibus_t *  ibus = NULL ;
@@ -517,10 +569,12 @@ im_ibus_new(
 		return  NULL ;
 	}
 
+#ifdef  DEBUG_MODKEY
 	if( getenv( "MOD_KEY_DEBUG"))
 	{
 		mod_key_debug = 1 ;
 	}
+#endif
 
 	if( ! ibus_bus)
 	{
@@ -544,14 +598,22 @@ im_ibus_new(
 			goto  error ;
 		}
 
+	#ifdef  DBUS_H
 		if( ! dbus_connection_get_unix_fd( ibus_connection_get_connection(
 				ibus_bus_get_connection( ibus_bus)) , &fd))
 		{
 			goto  error ;
 		}
-
+	#else
+		if( ( fd = g_socket_get_fd( g_socket_connection_get_socket(
+				g_dbus_connection_get_stream(
+					ibus_bus_get_connection( ibus_bus))))) == -1)
+		{
+			goto  error ;
+		}
+	#endif
 		(*syms->x_term_manager_add_fd)( fd , connection_handler) ;
-		(*syms->x_term_manager_add_fd)( IBUS_ID , connection_handler_idling) ;
+		(*syms->x_term_manager_add_fd)( IBUS_ID , connection_handler) ;
 
 		kik_list_new( im_ibus_t , ibus_list) ;
 	}
@@ -569,20 +631,23 @@ im_ibus_new(
 	ibus_input_context_set_capabilities( ibus->context ,
 		IBUS_CAP_PREEDIT_TEXT | IBUS_CAP_FOCUS | IBUS_CAP_SURROUNDING_TEXT) ;
 
-        g_signal_connect( ibus->context , "update-preedit-text" ,
+	g_signal_connect( ibus->context , "update-preedit-text" ,
 			G_CALLBACK( update_preedit_text) , ibus) ;
-        g_signal_connect( ibus->context , "commit-text" , G_CALLBACK( commit_text) , ibus) ;
+	g_signal_connect( ibus->context , "commit-text" , G_CALLBACK( commit_text) , ibus) ;
+	g_signal_connect( ibus->context , "forward-key-event" ,
+			G_CALLBACK( forward_key_event) , ibus) ;
 
 	ibus->term_encoding = term_encoding ;
 	ibus->parser_ibus = NULL ;
-	ibus->pressing_mod_key = 0 ;
-	ibus->mod_ignore_mask =  mod_ignore_mask ;
+	ibus->is_enabled = FALSE ;
 
 	if( ! ( ibus->parser_ibus = (*syms->ml_parser_new)( ML_UTF8)))
 	{
 		goto  error ;
 	}
 
+	memset( &ibus->prev_key , 0 , sizeof(XKeyEvent)) ;
+
 	/*
 	 * set methods of x_im_t
 	 */
