@@ -36,7 +36,17 @@ typedef enum  ml_char_encoding
 	ML_ISO8859_16 ,
 	ML_TCVN5712 ,
 
-	ML_ISCII ,	
+	ML_ISCII_ASSAMESE ,
+	ML_ISCII_BENGALI ,
+	ML_ISCII_GUJARATI ,
+	ML_ISCII_HINDI ,
+	ML_ISCII_KANNADA ,
+	ML_ISCII_MALAYALAM ,
+	ML_ISCII_ORIYA ,
+	ML_ISCII_PUNJABI ,
+	ML_ISCII_ROMAN ,
+	ML_ISCII_TAMIL ,
+	ML_ISCII_TELUGU ,
 	ML_VISCII ,
 	ML_KOI8_R ,
 	ML_KOI8_U ,
@@ -102,6 +112,9 @@ typedef enum  ml_char_encoding
 	( (encoding) == ML_ISO2022JP || (encoding) == ML_ISO2022JP2 || (encoding) == ML_ISO2022JP3 || \
 		(encoding) == ML_ISO2022KR || (encoding) == ML_ISO2022CN || (encoding) == ML_HZ )
 
+#define  IS_ISCII_ENCODING(encoding) \
+	( ML_ISCII_ASSAMESE <= (encoding) && (encoding) <= ML_ISCII_TELUGU)
+
 
 char *  ml_get_char_encoding_name( ml_char_encoding_t  encoding) ;
 
@@ -113,13 +126,12 @@ mkf_conv_t *  ml_conv_new( ml_char_encoding_t  encoding) ;
 
 int  ml_is_msb_set( mkf_charset_t  cs) ;
 
-int  ml_convert_to_ucs4( u_char *  ucs4_bytes , const u_char *  src_bytes , size_t  src_size ,
-	mkf_charset_t  cs) ;
+size_t  ml_char_encoding_convert( u_char *  dst , size_t  dst_len ,
+		ml_char_encoding_t  dst_encoding , u_char *  src , size_t  src_len ,
+		ml_char_encoding_t  src_encoding) ;
 
-int  ml_use_cp932_ucs_for_xft(void) ;
-
-int  ml_convert_to_xft_ucs4( u_char *  ucs4_bytes , const u_char *  src_bytes , size_t  src_size ,
-	mkf_charset_t  cs) ;
+size_t  ml_char_encoding_convert_with_parser( u_char *  dst , size_t  dst_len ,
+		ml_char_encoding_t  dst_encoding , mkf_parser_t *  parser) ;
 
 
 #endif
