@@ -62,7 +62,7 @@ int  ml_get_color_rgb( ml_color_t  color, u_int8_t *  red, u_int8_t *  green, u_
 int  ml_change_color_rgb( ml_color_t  color, u_int8_t  red, u_int8_t  green, u_int8_t  blue) ;
 
 int  ml_color_parse_rgb_name( u_int8_t *  red, u_int8_t *  green, u_int8_t *  blue,
-	const char *  name) ;
+	u_int8_t *  alpha, const char *  name) ;
 
 
 #endif
