@@ -94,6 +94,8 @@ int  ml_edit_vertical_forward_tabs( ml_edit_t *  edit , u_int  num) ;
 
 int  ml_edit_vertical_backward_tabs( ml_edit_t *  edit , u_int  num) ;
 
+#define  ml_edit_get_tab_size( edit)  ((edit)->tab_size)
+
 int  ml_edit_set_tab_size( ml_edit_t *  edit , u_int  tab_size) ;
 
 int  ml_edit_set_tab_stop( ml_edit_t *  edit) ;
@@ -106,9 +108,9 @@ ml_line_t *  ml_edit_get_line( ml_edit_t *  edit , int  row) ;
 
 int  ml_edit_set_modified_all( ml_edit_t *  edit) ;
 
-u_int ml_edit_get_cols( ml_edit_t *  edit) ;
+#define  ml_edit_get_cols( edit)  ((edit)->model.num_of_cols)
 
-u_int ml_edit_get_rows( ml_edit_t *  edit) ;
+#define  ml_edit_get_rows( edit)  ((edit)->model.num_of_rows)
 
 int  ml_edit_go_forward( ml_edit_t *  edit , int  flag) ;
 
@@ -128,19 +130,21 @@ int  ml_edit_set_relative_origin( ml_edit_t *  edit) ;
 
 int  ml_edit_set_absolute_origin( ml_edit_t *  edit) ;
 
-int  ml_edit_set_auto_wrap( ml_edit_t *  edit) ;
+int  ml_edit_set_auto_wrap( ml_edit_t *  edit , int  flag) ;
 
-int  ml_edit_unset_auto_wrap( ml_edit_t *  edit) ;
+int  ml_edit_set_bce_fg_color( ml_edit_t *  edit , ml_color_t  fg_color) ;
+
+int  ml_edit_set_bce_bg_color( ml_edit_t *  edit , ml_color_t  bg_color) ;
 
 int  ml_edit_save_cursor( ml_edit_t *  edit) ;
 
 int  ml_edit_restore_cursor( ml_edit_t *  edit) ;
 
-int  ml_cursor_char_index( ml_edit_t *  edit) ;
+#define  ml_cursor_char_index( edit)  ((edit)->cursor.char_index)
 
-int  ml_cursor_col( ml_edit_t *  edit) ;
+#define  ml_cursor_col( edit)  ((edit)->cursor.col)
 
-int  ml_cursor_row( ml_edit_t *  edit) ;
+#define  ml_cursor_row( edit)  ((edit)->cursor.row)
 
 #ifdef  DEBUG
 
