@@ -386,7 +386,7 @@ error2:
 }
 
 static int
-delete(
+final(
 	ml_pty_t *  p
 	)
 {
@@ -396,10 +396,6 @@ delete(
 
 	pty = (ml_pty_pipe_t*)p ;
 	
-#ifdef  __DEBUG
-	kik_debug_printf( KIK_DEBUG_TAG " ml_pty_delete is called for %p.\n" , pty) ;
-#endif
-
 	/*
 	 * TerminateProcess must be called before CloseHandle.
 	 * If pty->child_proc is not in child_procs, pty->child_proc is already
@@ -449,8 +445,6 @@ delete(
 	CloseHandle( pty->master_output) ;
 	CloseHandle( pty->rd_ev) ;
 
-	free( pty) ;
-
 	return  1 ;
 }
 
@@ -631,7 +625,7 @@ ml_pty_pipe_new(
 		CloseHandle( thrd) ;
 	}
 
-	if( ( pty = malloc( sizeof( ml_pty_pipe_t))) == NULL)
+	if( ( pty = calloc( 1 , sizeof( ml_pty_pipe_t))) == NULL)
 	{
 		return  NULL ;
 	}
@@ -704,9 +698,6 @@ ml_pty_pipe_new(
 		return  NULL ;
 	}
 
-	pty->rd_ch = '\0' ;
-	pty->rd_ready = 0 ;
-
 	snprintf( ev_name, sizeof(ev_name), "PTY_READ_READY%x", (int)pty->child_proc) ;
 	pty->rd_ev = CreateEvent( NULL, FALSE, FALSE, ev_name) ;
 #ifdef  __DEBUG
@@ -716,17 +707,11 @@ ml_pty_pipe_new(
 	pty->pty.master = (int)pty->master_output ;	/* XXX Cast HANDLE => int */
 	pty->pty.slave = (int)pty->slave_stdout ;	/* XXX Cast HANDLE => int */
 	pty->pty.child_pid = (pid_t)pty->child_proc ;	/* Cast HANDLE => pid_t */
-	pty->pty.buf = NULL ;
-	pty->pty.left = 0 ;
-	pty->pty.size = 0 ;
-	pty->pty.delete = delete ;
+	pty->pty.final = final ;
 	pty->pty.set_winsize = set_winsize ;
 	pty->pty.write = write_to_pty ;
 	pty->pty.read = read_pty ;
 
-	pty->pty.pty_listener = NULL ;
-	pty->pty.stored = NULL ;
-
 	if( set_winsize( &pty->pty , cols , rows) == 0)
 	{
 	#ifdef  DEBUG
