@@ -39,7 +39,7 @@ typedef struct ml_pty_unix
 /* --- static functions --- */
 
 static int
-delete(
+final(
 	ml_pty_t *  pty
 	)
 {
@@ -51,14 +51,12 @@ delete(
 #endif
 
 #ifdef  __DEBUG
-	kik_debug_printf( "%d fd is closed\n" , pty->master) ;
+	kik_debug_printf( "PTY fd %d is closed\n" , pty->master) ;
 #endif
 
 	kik_pty_close( pty->master) ;
 	close( pty->slave) ;
 
-	free( pty) ;
-
 	return  1 ;
 }
 
@@ -230,21 +228,15 @@ ml_pty_unix_new_with(
 {
 	ml_pty_t *  pty ;
 
-	if( ( pty = malloc( sizeof( ml_pty_unix_t))) == NULL)
+	if( ( pty = calloc( 1 , sizeof( ml_pty_unix_t))) == NULL)
 	{
 		return  NULL ;
 	}
 
-	pty->buf = NULL ;
-	pty->left = 0 ;
-	pty->size = 0 ;
-	pty->delete = delete ;
+	pty->final = final ;
 	pty->set_winsize = set_winsize ;
 	pty->write = write_to_pty ;
 	pty->read = read_pty ;
-  	pty->pty_listener = NULL ;
-	pty->stored = NULL ;
-
 	pty->master = master ;
 	pty->slave = slave ;
 
@@ -270,14 +262,6 @@ ml_pty_unix_new_with(
 		#endif
 		}
 	}
-#ifdef  USE_UTMP
-	else
-	{
-		/* Child process */
-
-		((ml_pty_unix_t*)pty)->utmp = NULL ;
-	}
-#endif
 
 	return  pty ;
 }
