@@ -38,7 +38,7 @@ ml_term_new(
 {
 	ml_term_t *  term ;
 
-	if( ( term = malloc( sizeof( ml_term_t))) == NULL)
+	if( ( term = calloc( 1 , sizeof( ml_term_t))) == NULL)
 	{
 	#ifdef  DEBUG
 		kik_warn_printf( KIK_DEBUG_TAG " malloc failed.\n") ;
@@ -47,9 +47,6 @@ ml_term_new(
 		return  NULL ;
 	}
 
-	term->pty = NULL ;
-	term->pty_listener = NULL ;
-
 	if( ( term->screen = ml_screen_new( cols , rows ,
 				tab_size , log_size , use_bce , bs_mode)) == NULL)
 	{
@@ -79,7 +76,6 @@ ml_term_new(
 		goto  error ;
 	}
 
-	term->shape = NULL ;
 	term->vertical_mode = vertical_mode ;
 	term->bidi_mode = bidi_mode ;
 	term->use_bidi = use_bidi ;
@@ -88,12 +84,6 @@ ml_term_new(
 
 	term->is_auto_encoding = is_auto_encoding ;
 
-	term->win_name = NULL ;
-	term->icon_name = NULL ;
-	term->icon_path = NULL ;
-
-	term->is_attached = 0 ;
-
 	return  term ;
 
 error:
@@ -127,6 +117,9 @@ ml_term_delete(
 		(*term->shape->delete)( term->shape) ;
 	}
 
+#ifdef  MULTI_WINDOWS_PER_PTY
+	free( term->win_id) ;
+#endif
 	free( term->win_name) ;
 	free( term->icon_name) ;
 	free( term->icon_path) ;
@@ -896,6 +889,20 @@ ml_term_enter_backscroll_mode(
 	return  ml_enter_backscroll_mode( term->screen) ;
 }
 
+#ifdef  MULTI_WINDOWS_PER_PTY
+int
+ml_term_set_window_id(
+	ml_term_t *  term ,
+	char *  id		/* Could be NULL */
+	)
+{
+	free( term->win_id) ;
+	term->win_id = id ? strdup( id) : NULL ;
+
+	return  1 ;
+}
+#endif
+
 int
 ml_term_set_window_name(
 	ml_term_t *  term ,
