@@ -437,7 +437,7 @@ put_char(
 		}
 		else
 		{
-			if( ( prev = ml_screen_get_n_prev_char( vt100_parser->screen , ++n)) == NULL)
+			if( ! ( prev = ml_screen_get_n_prev_char( vt100_parser->screen , ++n)))
 			{
 				return ;
 			}
@@ -558,16 +558,51 @@ restore_cursor(
 }
 
 static void
-resize_columns(
+resize_by_char(
 	ml_vt100_parser_t *  vt100_parser ,
-	u_int  cols
+	u_int  cols ,
+	u_int  rows
 	)
 {
-	if( HAS_XTERM_LISTENER(vt100_parser,resize_columns))
+	if( HAS_XTERM_LISTENER(vt100_parser,resize))
+	{
+		/*
+		 * XXX Not compatible with xterm.
+		 * cols or rows == 0 means full screen width or height in xterm.
+		 * Note that ml_vt100_parser.c depends on following behavior.
+		 */
+		if( cols == 0)
+		{
+			cols = ml_screen_get_cols( vt100_parser->screen) ;
+		}
+
+		if( rows == 0)
+		{
+			rows = ml_screen_get_rows( vt100_parser->screen) ;
+		}
+
+		ml_set_pty_winsize( vt100_parser->pty , cols , rows) ;
+		ml_screen_resize( vt100_parser->screen , cols , rows) ;
+
+		stop_vt100_cmd( vt100_parser , 0) ;
+		(*vt100_parser->xterm_listener->resize)(
+			vt100_parser->xterm_listener->self , 0 , 0) ;
+		start_vt100_cmd( vt100_parser , 0) ;
+	}
+}
+
+static void
+resize_by_pixel(
+	ml_vt100_parser_t *  vt100_parser ,
+	u_int  width ,
+	u_int  height
+	)
+{
+	if( HAS_XTERM_LISTENER(vt100_parser,resize))
 	{
 		stop_vt100_cmd( vt100_parser , 0) ;
-		(*vt100_parser->xterm_listener->resize_columns)(
-			vt100_parser->xterm_listener->self , cols) ;
+		(*vt100_parser->xterm_listener->resize)(
+			vt100_parser->xterm_listener->self , width , height) ;
 		start_vt100_cmd( vt100_parser , 0) ;
 	}
 }
@@ -1216,6 +1251,7 @@ set_selection(
 	return  1 ;
 }
 
+
 static void
 clear_line_all(
 	ml_vt100_parser_t *  vt100_parser
@@ -1693,7 +1729,7 @@ parse_vt100_escape_sequence(
 						/* XTERM compatibility [#1048321] */
 						clear_display_all( vt100_parser) ;
 
-						resize_columns( vt100_parser , 132) ;
+						resize_by_char( vt100_parser , 132 , 0) ;
 					}
 				#if  0
 					else if( ps[0] == 4)
@@ -1893,7 +1929,7 @@ parse_vt100_escape_sequence(
 						/* XTERM compatibility [#1048321] */
 						clear_display_all( vt100_parser) ;
 
-						resize_columns( vt100_parser , 80) ;
+						resize_by_char( vt100_parser , 80 , 0) ;
 					}
 				#if  0
 					else if( ps[0] == 4)
@@ -2559,6 +2595,22 @@ parse_vt100_escape_sequence(
 
 				save_cursor( vt100_parser) ;
 			}
+			else if( *str_p == 't')
+			{
+				/* "CSI t" */
+
+				if( num == 3)
+				{
+					if( ps[0] == 4)
+					{
+						resize_by_pixel( vt100_parser , ps[2] , ps[1]) ;
+					}
+					else if( ps[0] == 8)
+					{
+						resize_by_char( vt100_parser , ps[2] , ps[1]) ;
+					}
+				}
+			}
 			else if( *str_p == 'u')
 			{
 				/* "CSI u" */
@@ -2775,6 +2827,28 @@ parse_vt100_escape_sequence(
 
 				set_selection( vt100_parser , pt) ;
 			}
+		#ifdef  MULTI_WINDOWS_PER_PTY
+			else if( ps == 115)
+			{
+				u_char *  p ;
+
+				if( *pt && ( p = alloca( 14 + strlen(pt) + 1)))
+				{
+					sprintf( p , "open_screen %s" , pt) ;
+					config_protocol_set( vt100_parser , p , 0) ;
+				}
+			}
+			else if( ps == 116)
+			{
+				u_char *  p ;
+
+				if( *pt && ( p = alloca( 15 + strlen(pt) + 1)))
+				{
+					sprintf( p , "close_screen %s" , pt) ;
+					config_protocol_set( vt100_parser , p , 0) ;
+				}
+			}
+		#endif
 			else if( ps == 5379)
 			{
 				/* "OSC 5379" set */
@@ -3318,36 +3392,23 @@ ml_vt100_parser_new(
 {
 	ml_vt100_parser_t *  vt100_parser ;
 
-	if( ( vt100_parser = malloc( sizeof( ml_vt100_parser_t))) == NULL)
+	if( ( vt100_parser = calloc( 1 , sizeof( ml_vt100_parser_t))) == NULL)
 	{
 		return  NULL ;
 	}
 
-	vt100_parser->left = 0 ;
-	vt100_parser->len = 0 ;
-
 	ml_str_init( vt100_parser->buffer.chars , PTY_WR_BUFFER_SIZE) ;	
-	vt100_parser->buffer.len = 0 ;
-	vt100_parser->buffer.last_ch = NULL ;
 	vt100_parser->buffer.output_func = ml_screen_overwrite_chars ;
 
 	vt100_parser->screen = screen ;
-	vt100_parser->pty = NULL ;
-
-	vt100_parser->xterm_listener = NULL ;
-	vt100_parser->config_listener = NULL ;
 
 	vt100_parser->log_file = -1 ;
 	
 	vt100_parser->cs = UNKNOWN_CS ;
 	vt100_parser->fg_color = ML_FG_COLOR ;
 	vt100_parser->bg_color = ML_BG_COLOR ;
-	vt100_parser->is_bold = 0 ;
-	vt100_parser->is_underlined = 0 ;
-	vt100_parser->is_reversed = 0 ;
 	vt100_parser->use_char_combining = use_char_combining ;
 	vt100_parser->use_multi_col_char = use_multi_col_char ;
-	vt100_parser->logging_vt_seq = 0 ;
 
 	vt100_parser->unicode_policy = policy ;
 
@@ -3365,24 +3426,10 @@ ml_vt100_parser_new(
 
 	vt100_parser->encoding = encoding ;
 
-	vt100_parser->is_dec_special_in_gl = 0 ;
-	vt100_parser->is_so = 0 ;
-	vt100_parser->is_dec_special_in_g0 = 0 ;
 	vt100_parser->is_dec_special_in_g1 = 1 ;
 
 	ml_vt100_parser_set_col_size_of_width_a( vt100_parser , col_size_a) ;
 	
-	vt100_parser->saved_normal.is_saved = 0 ;
-        vt100_parser->saved_alternate.is_saved = 0 ;
-
-	vt100_parser->mouse_mode = 0 ;
-	vt100_parser->is_app_keypad = 0 ;
-	vt100_parser->is_app_cursor_keys = 0 ;
-	vt100_parser->is_app_escape = 0 ;
-	vt100_parser->is_bracketed_paste_mode = 0 ;
-
-	vt100_parser->im_is_active = 0 ;
-
 	return  vt100_parser ;
 
 error:
