@@ -276,19 +276,20 @@ get_fc_col_width(
 	}
 	else if( strcmp( fc_size_type , FC_SIZE) == 0)
 	{
-		double  widthpix ;
-		double  widthmm ;
 		double  dpi ;
 
-		widthpix = DisplayWidth( font->display , DefaultScreen(font->display)) ;
-		widthmm = DisplayWidthMM( font->display , DefaultScreen(font->display)) ;
-
 		if( dpi_for_fc)
 		{
 			dpi = dpi_for_fc ;
 		}
 		else
 		{
+			double  widthpix ;
+			double  widthmm ;
+
+			widthpix = DisplayWidth( font->display , DefaultScreen(font->display)) ;
+			widthmm = DisplayWidthMM( font->display , DefaultScreen(font->display)) ;
+
 			dpi = (widthpix * 254) / (widthmm * 10) ;
 		}
 
@@ -332,11 +333,13 @@ fc_pattern_create(
 		FcPatternAddInteger( pattern , FC_SLANT , slant) ;
 	}
 	FcPatternAddInteger( pattern , FC_SPACING , ch_width > 0 ? FC_MONO : FC_PROPORTIONAL) ;
+#ifdef  USE_TYPE_XFT
 	if( ch_width > 0)
 	{
 		/* XXX FC_CHAR_WIDTH doesn't make effect in cairo ... */
 		FcPatternAddInteger( pattern , FC_CHAR_WIDTH , ch_width) ;
 	}
+#endif
 	if( aa_opt)
 	{
 		FcPatternAddBool( pattern , FC_ANTIALIAS , aa_opt == 1 ? True : False) ;
@@ -455,11 +458,21 @@ cairo_font_open(
 
 	options = cairo_font_options_create() ;
 	cairo_get_font_options( cairo , options) ;
-	/* CAIRO_HINT_METRICS_ON disarranges column width by boldening etc. */
+#ifndef  CAIRO_FORCE_DOUBLE_DRAWING
+	/*
+	 * XXX
+	 * CAIRO_HINT_METRICS_OFF has bad effect, but CAIRO_HINT_METRICS_ON disarranges
+	 * column width by boldening etc.
+	 */
 	cairo_font_options_set_hint_metrics( options , CAIRO_HINT_METRICS_OFF) ;
-	/* cairo_font_options_set_hint_style( options , CAIRO_HINT_STYLE_NONE) ; */
-	/* cairo_font_options_set_antialias( options , CAIRO_ANTIALIAS_SUBPIXEL) ; */
-	/* cairo_font_options_set_subpixel_order( options , CAIRO_SUBPIXEL_ORDER_RGB) ; */
+#else
+	/* For performance */
+	cairo_font_options_set_hint_style( options , CAIRO_HINT_STYLE_NONE) ;
+#endif
+#if  0
+	cairo_font_options_set_antialias( options , CAIRO_ANTIALIAS_SUBPIXEL) ;
+	cairo_font_options_set_subpixel_order( options , CAIRO_SUBPIXEL_ORDER_RGB) ;
+#endif
 	cairo_ft_font_options_substitute( options , pattern) ;
 
 	FcDefaultSubstitute( pattern) ;
@@ -919,7 +932,15 @@ xft_calculate_char_width(
 		return  0 ;
 	}
 
-	return  extents.xOff ;
+	if( extents.xOff < 0)
+	{
+		/* Some (indic) fonts could return minus value as text width. */
+		return  0 ;
+	}
+	else
+	{
+		return  extents.xOff ;
+	}
 }
 
 #endif
@@ -1037,6 +1058,7 @@ cairo_calculate_char_width(
 {
 	u_char  utf8[UTF_MAX_SIZE + 1] ;
 	cairo_text_extents_t  extents ;
+	int  width ;
 
 	utf8[ x_convert_ucs_to_utf8( utf8 , mkf_bytes_to_int( ch , len))] = '\0' ;
 	cairo_scaled_font_text_extents( font->cairo_font , utf8 , &extents) ;
@@ -1046,7 +1068,15 @@ cairo_calculate_char_width(
 		ch[0] , extents.x_bearing , extents.width , extents.x_advance) ;
 #endif
 
-	return  DOUBLE_ROUNDUP_TO_INT(extents.x_advance) ;
+	if( ( width = DOUBLE_ROUNDUP_TO_INT(extents.x_advance)) < 0)
+	{
+		return  0 ;
+	}
+	else
+	{
+		/* Some (indic) fonts could return minus value as text width. */
+		return  width ;
+	}
 }
 
 #endif
