@@ -52,7 +52,6 @@ static char *  taafont_file = "mlterm/taafont" ;
 static cs_table_t  cs_table[] =
 {
 	{ "ISO10646_UCS4_1" , ISO10646_UCS4_1 } ,
-	{ "ISO10646_UCS2_1" , ISO10646_UCS2_1 } ,
 
 	{ "DEC_SPECIAL" , DEC_SPECIAL } ,
 	{ "ISO8859_1" , ISO8859_1_R } ,
@@ -1193,7 +1192,7 @@ match_font_configs(
 	return  size ;
 }
 
-x_font_config_t *
+static x_font_config_t *
 create_shared_font_config(
 	x_type_engine_t  type_engine ,
 	x_font_present_t  font_present
@@ -1233,6 +1232,7 @@ create_shared_font_config(
 	return  NULL ;
 }
 
+
 /* --- global functions --- */
 
 int
@@ -1532,7 +1532,7 @@ x_customize_font_name(
 	}
 
 #ifdef  DEBUG
-	kik_warn_printf( "Set %x font size %d => fontname %s for size.\n" ,
+	kik_debug_printf( KIK_DEBUG_TAG " Set %x font size %d => fontname %s.\n" ,
 		font , font_size , fontname) ;
 #endif
 
@@ -1555,7 +1555,7 @@ x_customize_default_font_name(
 
 	if( is_valid_default_font_format( fontname) == 0)
 	{
-		kik_warn_printf( " %s is invalid format for font name.\n") ;
+		kik_msg_printf( "%s is invalid format for font name.\n") ;
 
 		return  0 ;
 	}
@@ -1598,7 +1598,8 @@ x_customize_default_font_name(
 	}
 
 #ifdef  DEBUG
-	kik_warn_printf( "Set %x default font => fontname %s for size.\n" , font , fontname) ;
+	kik_debug_printf( KIK_DEBUG_TAG " Set %x default font => fontname %s.\n" ,
+		font , fontname) ;
 #endif
 
 	return  1 ;
@@ -1917,7 +1918,7 @@ x_get_all_config_font_names(
 	char *  font_name_list ;
 	size_t  list_len ;
 	char *  p ;
-	int  count ;
+	u_int  count ;
 
 	array = get_font_name_pairs_array( &size , get_font_name_table( font_config , font_size)) ;
 	d_array = get_font_name_pairs_array( &d_size , font_config->default_font_name_table) ;
@@ -1982,7 +1983,11 @@ x_get_all_config_font_names(
 		}
 	}
 
-	*(p - 1) = '\0' ;
+	if( p > font_name_list)
+	{
+		--p ;
+	}
+	*p = '\0' ;
 
 #ifdef  DEBUG
 	kik_debug_printf( KIK_DEBUG_TAG " Font list is %s\n" , font_name_list) ;
