@@ -233,13 +233,6 @@ draw_screen_vertical(
 
 	x_window_resize( &cand_screen->window , win_width , win_height , 0) ;
 
-	/*
-	 * draw border
-	 */
-	x_window_draw_rect_frame( &cand_screen->window , 0 , 0 ,
-				  win_width + MARGIN*2 - 1 ,
-				  win_height + MARGIN*2 - 1);
-
 	/*
 	 * digits and candidates
 	 */
@@ -419,13 +412,6 @@ draw_screen_horizontal(
 
 	x_window_resize( &cand_screen->window , win_width , win_height , 0) ;
 
-	/*
-	 * draw border
-	 */
-	x_window_draw_rect_frame( &cand_screen->window , 0 , 0 ,
-				  win_width + MARGIN*2 - 1 ,
-				  win_height + MARGIN*2 - 1);
-
 	for( i = top ; i <= last; i++)
 	{
 		u_int  num_of_digits ;
@@ -883,6 +869,11 @@ window_exposed(
 	)
 {
 	draw_screen( (x_im_candidate_screen_t *) win) ;
+
+	/* draw border */
+	x_window_draw_rect_frame( win , -MARGIN , -MARGIN ,
+				  win->width + MARGIN - 1 ,
+				  win->height + MARGIN - 1);
 }
 
 static void
@@ -939,11 +930,7 @@ button_pressed(
 		return ;
 	}
 
-	draw_screen( cand_screen) ;
-
 	(*cand_screen->listener.selected)( cand_screen->listener.self , index) ;
-
-
 }
 
 
