@@ -51,13 +51,6 @@ draw_screen(
 	x_window_resize( &stat_screen->window , width ,
 			 xfont->height + LINE_SPACE, 0) ;
 
-	/*
-	 * draw border
-	 */
-	x_window_draw_rect_frame( &stat_screen->window , 0 , 0 ,
-				  width + MARGIN*2 - 1 ,
-				  xfont->height + LINE_SPACE + MARGIN*2 - 1);
-
 	x_draw_str_to_eol( &stat_screen->window ,
 			   stat_screen->font_man ,
 			   stat_screen->color_man ,
@@ -273,6 +266,11 @@ window_exposed(
 	)
 {
 	draw_screen( (x_im_status_screen_t *) win) ;
+
+	/* draw border */
+	x_window_draw_rect_frame( win , -MARGIN , -MARGIN ,
+				  win->width + MARGIN - 1 ,
+				  win->height + MARGIN - 1);
 }
 
 static void
