@@ -18,7 +18,7 @@ static char *   sb_mode_name_table[] =
 /* --- global functions --- */
 
 x_sb_mode_t
-x_get_sb_mode(
+x_get_sb_mode_by_name(
 	char *  name
 	)
 {
