@@ -555,7 +555,7 @@ change_sb_mode(
 	}
 	else
 	{
-		if( sb_screen->sb_mode == SBM_NONE) ;
+		if( sb_screen->sb_mode == SBM_NONE)
 		{
 			x_window_map( &sb_screen->scrollbar.window) ;
 			
@@ -649,7 +649,7 @@ x_sb_screen_new(
 
 	/*
 	 * event callbacks.
-	 */	
+	 */
 	sb_screen->screen_scroll_listener.self = sb_screen ;
 	sb_screen->screen_scroll_listener.bs_mode_entered = NULL ;
 	sb_screen->screen_scroll_listener.bs_mode_exited = bs_mode_exited ;
