@@ -16,6 +16,7 @@
 #include  <X11/Xatom.h>
 #include  <kiklib/kik_debug.h>
 #include  <kiklib/kik_mem.h>	/* realloc/free */
+#include  <kiklib/kik_util.h>	/* K_MAX */
 
 #include  "x_xic.h"
 #include  "x_picture.h"
@@ -346,8 +347,8 @@ notify_configure_to_children(
 		}
 		else if( win->window_exposed)
 		{
-			(*win->window_exposed)( win , 0 , 0 , win->width , win->height) ;
 			x_window_clear_margin_area( win) ;
+			(*win->window_exposed)( win , 0 , 0 , win->width , win->height) ;
 		}
 	#if  0
 		else
@@ -787,42 +788,12 @@ x_window_init(
 	int  create_gc
 	)
 {
-	/*
-	 * these values are set later
-	 */
-
-	win->disp = NULL ;
-	
-	win->my_window = None ;
-
-#if  ! defined(NO_DYNAMIC_LOAD_TYPE) || defined(USE_TYPE_XFT)
-	win->xft_draw = NULL ;
-#endif
-#if  ! defined(NO_DYNAMIC_LOAD_TYPE) || defined(USE_TYPE_CAIRO)
-	win->cairo_draw = NULL ;
-#endif
-
-	win->gc = NULL ;
+	memset( win , 0 , sizeof( x_window_t)) ;
 
 	win->fg_color.pixel = 0xff000000 ;
-	win->fg_color.red = 0x0 ;
-	win->fg_color.green = 0x0 ;
-	win->fg_color.blue = 0x0 ;
 	win->fg_color.alpha = 0xff ;
 	memset( &win->bg_color , 0xff , sizeof(win->bg_color)) ;
 
-	win->parent_window = None ;
-	win->parent = NULL ;
-	win->children = NULL ;
-	win->num_of_children = 0 ;
-
-	win->pic_mod = NULL ;
-
-	win->wall_picture_is_set = 0 ;
-	win->is_transparent = 0 ;
-
-	win->cursor_shape = 0 ;
-
 	win->event_mask = ExposureMask | FocusChangeMask | PropertyChangeMask ;
 
 	/* If wall picture is set, scrollable will be 0. */
@@ -839,12 +810,8 @@ x_window_init(
 	/* This flag will map window automatically in x_window_show() */
 	win->is_mapped = 1 ;
 
-	win->is_sel_owner = 0 ;
-
 	win->create_gc = create_gc ;
 
-	win->x = 0 ;
-	win->y = 0 ;
 	win->width = width ;
 	win->height = height ;
 	win->min_width = min_width ;
@@ -855,39 +822,9 @@ x_window_init(
 	win->height_inc = height_inc ;
 	win->margin = margin ;
 
-	win->xic = NULL ;
-	win->xim = NULL ;
-	win->xim_listener = NULL ;
-
-	win->prev_clicked_time = 0 ;
 	win->prev_clicked_button = -1 ;
-	win->click_num = 0 ;
-	win->button_is_pressing = 0 ;
-	win->dnd = NULL ;
-	win->app_name = "mlterm" ;	/* Can be changed in x_display_show_root(). */
 
-	win->window_realized = NULL ;
-	win->window_finalized = NULL ;
-	win->window_exposed = NULL ;
-	win->update_window = NULL ;
-	win->window_focused = NULL ;
-	win->window_unfocused = NULL ;
-	win->key_pressed = NULL ;
-	win->pointer_motion = NULL ;
-	win->button_motion = NULL ;
-	win->button_released = NULL ;
-	win->button_pressed = NULL ;
-	win->button_press_continued = NULL ;
-	win->window_resized = NULL ;
-	win->child_window_resized = NULL ;
-	win->selection_cleared = NULL ;
-	win->xct_selection_requested = NULL ;
-	win->utf_selection_requested = NULL ;
-	win->xct_selection_notified = NULL ;
-	win->utf_selection_notified = NULL ;
-	win->window_deleted = NULL ;
-	win->mapping_notify = NULL ;
-	win->set_xdnd_config = NULL ;
+	win->app_name = "mlterm" ;	/* Can be changed in x_display_show_root(). */
 
 	return	1 ;
 }
@@ -899,7 +836,7 @@ x_window_final(
 {
 	u_int  count ;
 
-#ifdef  __DEBUG
+#ifdef  DEBUG
 	kik_debug_printf( "[deleting child windows]\n") ;
 	x_window_dump_children( win) ;
 #endif
@@ -1072,8 +1009,8 @@ x_window_set_wall_picture(
 
 	if( win->window_exposed)
 	{
-		(*win->window_exposed)( win , 0 , 0 , win->width , win->height) ;
 		x_window_clear_margin_area( win) ;
+		(*win->window_exposed)( win , 0 , 0 , win->width , win->height) ;
 	}
 #if  0
 	else
@@ -1126,8 +1063,8 @@ x_window_unset_wall_picture(
 
 	if( win->window_exposed)
 	{
-		(*win->window_exposed)( win , 0 , 0 , win->width , win->height) ;
 		x_window_clear_margin_area( win) ;
+		(*win->window_exposed)( win , 0 , 0 , win->width , win->height) ;
 	}
 #if  0
 	else
@@ -1197,8 +1134,8 @@ x_window_unset_transparent(
 
 		if( win->window_exposed)
 		{
-			(*win->window_exposed)( win , 0 , 0 , win->width , win->height) ;
 			x_window_clear_margin_area( win) ;
+			(*win->window_exposed)( win , 0 , 0 , win->width , win->height) ;
 		}
 	#if  0
 		else
@@ -1610,8 +1547,25 @@ x_window_resize(
 		return  0 ;
 	}
 
-	win->width = width ;
-	win->height = height ;
+	/* Max width of each window is DisplayWidth(). */
+	if( DisplayWidth( win->disp->display , win->disp->screen) < width)
+	{
+		win->width = DisplayWidth( win->disp->display , win->disp->screen) ;
+	}
+	else
+	{
+		win->width = width ;
+	}
+
+	/* Max height of each window is DisplayHeight(). */
+	if( DisplayHeight( win->disp->display , win->disp->screen) < height)
+	{
+		win->height = DisplayHeight( win->disp->display , win->disp->screen) ;
+	}
+	else
+	{
+		win->height = height ;
+	}
 
 	if( (flag & NOTIFY_TO_PARENT) && win->parent && win->parent->child_window_resized)
 	{
@@ -1816,6 +1770,7 @@ x_window_clear(
 	u_int	height
 	)
 {
+#ifdef  AUTO_CLEAR_MARGIN
 	if( x + width >= win->width)
 	{
 		/* Clearing margin area */
@@ -1823,9 +1778,11 @@ x_window_clear(
 	}
 
 	if( x > 0)
+#endif
 	{
 		x += win->margin ;
 	}
+#ifdef  AUTO_CLEAR_MARGIN
 	else
 	{
 		/* Clearing margin area */
@@ -1839,14 +1796,17 @@ x_window_clear(
 	}
 
 	if( y > 0)
+#endif
 	{
 		y += win->margin ;
 	}
+#ifdef  AUTO_CLEAR_MARGIN
 	else
 	{
 		/* Clearing margin area */
 		height += win->margin ;
 	}
+#endif
 
 	XClearArea( win->disp->display , win->my_window , x , y , width , height , False) ;
 
@@ -1858,20 +1818,18 @@ x_window_clear_margin_area(
 	x_window_t *  win
 	)
 {
-	if( win->margin == 0)
+	if( win->margin > 0)
 	{
-		return  1 ;
+		XClearArea( win->disp->display , win->my_window ,
+			0 , 0 , win->margin , ACTUAL_HEIGHT(win) , 0) ;
+		XClearArea( win->disp->display , win->my_window ,
+			win->margin , 0 , win->width , win->margin , 0) ;
+		XClearArea( win->disp->display , win->my_window , win->width + win->margin ,
+			0 , win->margin , ACTUAL_HEIGHT(win) , 0) ;
+		XClearArea( win->disp->display , win->my_window , win->margin ,
+			win->height + win->margin , win->width , win->margin , 0) ;
 	}
 
-	XClearArea( win->disp->display , win->my_window ,
-		0 , 0 , win->margin , ACTUAL_HEIGHT(win) , 0) ;
-	XClearArea( win->disp->display , win->my_window ,
-		win->margin , 0 , win->width , win->margin , 0) ;
-	XClearArea( win->disp->display , win->my_window , win->width + win->margin ,
-		0 , win->margin , ACTUAL_HEIGHT(win) , 0) ;
-	XClearArea( win->disp->display , win->my_window , win->margin ,
-		win->height + win->margin , win->width , win->margin , 0) ;
-
 	return  1 ;
 }
 
@@ -2221,11 +2179,95 @@ x_window_receive_event(
 	         ( event->type == GraphicsExpose &&
 		   event->xgraphicsexpose.drawable == win->my_window) )
 	{
+		XEvent  next_ev ;
 		int  x ;
 		int  y ;
 		u_int  width ;
 		u_int  height ;
 		int  margin_area_exposed ;
+	#ifdef  __DEBUG
+		int  nskip = 0 ;
+	#endif
+
+		/* Optimize redrawing. */
+		while( XCheckTypedWindowEvent( win->disp->display , win->my_window ,
+			Expose , &next_ev))
+		{
+			XEvent  ev ;
+			int  diff ;
+
+			ev = *event ;
+
+		#ifdef  __DEBUG
+			kik_debug_printf( KIK_DEBUG_TAG
+				" x %d y %d w %d h %d + x %d y %d w %d h %d ->" ,
+				ev.xexpose.x , ev.xexpose.y ,
+				ev.xexpose.width , ev.xexpose.height ,
+				next_ev.xexpose.x , next_ev.xexpose.y ,
+				next_ev.xexpose.width , next_ev.xexpose.height) ;
+		#endif
+
+			if( ( diff = ev.xexpose.x - next_ev.xexpose.x) > 0)
+			{
+				ev.xexpose.width += diff ;
+				ev.xexpose.x = next_ev.xexpose.x ;
+			}
+
+			if( ( diff = next_ev.xexpose.x + next_ev.xexpose.width -
+			              ev.xexpose.x - ev.xexpose.width) > 0)
+			{
+				ev.xexpose.width += diff ;
+			}
+
+			if( ( diff = ev.xexpose.y - next_ev.xexpose.y) > 0)
+			{
+				ev.xexpose.height += diff ;
+				ev.xexpose.y = next_ev.xexpose.y ;
+			}
+
+			if( ( diff = next_ev.xexpose.y + next_ev.xexpose.height -
+			             ev.xexpose.y - ev.xexpose.height) > 0)
+			{
+				ev.xexpose.height += diff ;
+			}
+
+		#ifdef  __DEBUG
+			kik_msg_printf( " x %d y %d w %d h %d\n" ,
+				ev.xexpose.x , ev.xexpose.y ,
+				ev.xexpose.width , ev.xexpose.height) ;
+		#endif
+
+			/* Minimum character size is regarded as w5 x h10. */
+			if( ( ev.xexpose.width * ev.xexpose.height) / 4  >=
+			    ( K_MAX( event->xexpose.width , 5) *
+			      K_MAX( event->xexpose.height , 10) +
+			      K_MAX( next_ev.xexpose.width , 5) *
+			      K_MAX( next_ev.xexpose.height , 10)) / 3)
+			{
+				/* Redrawing area is increased over 33.3% by this combination. */
+
+			#ifdef  __DEBUG
+				kik_msg_printf( "=> Discard combination of XExposeEvents "
+						"because of inefficiency.\n") ;
+			#endif
+
+				XPutBackEvent( win->disp->display , &next_ev) ;
+
+				break ;
+			}
+			else
+			{
+			#ifdef  __DEBUG
+				nskip ++ ;
+			#endif
+
+				*event = ev ;
+			}
+		}
+
+	#ifdef  __DEBUG
+		kik_debug_printf( KIK_DEBUG_TAG " skipped %d expose events.\n" , nskip) ;
+	#endif
 
 		margin_area_exposed = 0 ;
 		
@@ -2297,12 +2339,12 @@ x_window_receive_event(
 
 		if( win->window_exposed)
 		{
-			(*win->window_exposed)( win , x , y , width , height) ;
-
 			if( margin_area_exposed)
 			{
 				x_window_clear_margin_area( win) ;
 			}
+
+			(*win->window_exposed)( win , x , y , width , height) ;
 		}
 	#if  0
 		else
@@ -3180,11 +3222,11 @@ x_window_draw_rect_frame(
 {
 	XPoint  points[5] =
 	{
-		{ x1 , y1 } ,
-		{ x1 , y2 } ,
-		{ x2 , y2 } ,
-		{ x2 , y1 } ,
-		{ x1 , y1 } ,
+		{ x1 += win->margin	, y1 += win->margin } ,
+		{ x1			, y2 += win->margin } ,
+		{ x2 += win->margin	, y2 } ,
+		{ x2			, y1 } ,
+		{ x1			, y1 } ,
 	} ;
 
 	restore_fg_color(win) ;
