@@ -14,7 +14,6 @@
 
 #include  <kiklib/kik_types.h>
 #include  <mkf/mkf_parser.h>
-#include  <ml_char.h>
 
 #include  "x_display.h"
 #include  "x_font.h"
@@ -119,7 +118,6 @@ typedef struct  x_window
 
 #ifdef  USE_WIN32GUI
 	WORD  update_window_flag ;
-	Pixmap  wall_picture ;
 #endif
 
 	/* button */
@@ -148,8 +146,12 @@ typedef struct  x_window
 	 * flags etc.
 	 */
 
-	int8_t  is_sel_owner ;
+#ifdef  USE_WIN32GUI
+	Pixmap  wall_picture ;
+#else
 	int8_t  wall_picture_is_set ;	/* Actually set picture (including transparency) or not. */
+#endif
+	int8_t  is_sel_owner ;
 	int8_t  is_transparent ;
 	int8_t  is_scrollable ;
 	int8_t  is_focused ;
@@ -215,6 +217,12 @@ int  x_window_set_wall_picture( x_window_t *  win , Pixmap  pic) ;
 
 int  x_window_unset_wall_picture( x_window_t *  win) ;
 
+#ifdef  USE_WIN32GUI
+#define  x_window_has_wall_picture( win)  ((win)->wall_picture != None)
+#else
+#define  x_window_has_wall_picture( win)  ((win)->wall_picture_is_set)
+#endif
+
 int  x_window_set_transparent( x_window_t *  win , x_picture_modifier_ptr_t  pic_mod) ;
 
 int  x_window_unset_transparent( x_window_t *  win) ;
@@ -278,28 +286,28 @@ void  x_window_idling( x_window_t *  win) ;
 
 int  x_window_receive_event( x_window_t *  win , XEvent *  event) ;
 
-size_t  x_window_get_str( x_window_t *  win , u_char *  seq , size_t  seq_len , mkf_parser_t **  parser ,
-	KeySym *  keysym , XKeyEvent *  event) ;
+size_t  x_window_get_str( x_window_t *  win , u_char *  seq , size_t  seq_len ,
+	mkf_parser_t **  parser , KeySym *  keysym , XKeyEvent *  event) ;
 
 int  x_window_is_scrollable( x_window_t *  win) ;
 
 int  x_window_scroll_upward( x_window_t *  win , u_int  height) ;
 
-int  x_window_scroll_upward_region( x_window_t *  win , int  boundary_start , int  boundary_end ,
-	u_int  height) ;
+int  x_window_scroll_upward_region( x_window_t *  win ,
+	int  boundary_start , int  boundary_end , u_int  height) ;
 
 int  x_window_scroll_downward( x_window_t *  win , u_int  height) ;
 
-int  x_window_scroll_downward_region( x_window_t *  win , int  boundary_start , int  boundary_end ,
-	u_int  height) ;
+int  x_window_scroll_downward_region( x_window_t *  win ,
+	int  boundary_start , int  boundary_end , u_int  height) ;
 
 int  x_window_scroll_leftward( x_window_t *  win , u_int  width) ;
 
-int  x_window_scroll_leftward_region( x_window_t *  win , int  boundary_start , int  boundary_end ,
-	u_int  width) ;
+int  x_window_scroll_leftward_region( x_window_t *  win ,
+	int  boundary_start , int  boundary_end , u_int  width) ;
 
-int  x_window_scroll_rightward_region( x_window_t *  win , int  boundary_start , int  boundary_end ,
-	u_int  width) ;
+int  x_window_scroll_rightward_region( x_window_t *  win ,
+	int  boundary_start , int  boundary_end , u_int  width) ;
 
 int  x_window_scroll_rightward( x_window_t *  win , u_int  width) ;
 
