@@ -593,7 +593,7 @@ get_key_state(void)
 	}
 	if( GetKeyState(VK_MENU) < 0)
 	{
-		state |= ModMask ;
+		state |= Mod1Mask ;
 	}
 
 	return  state ;
@@ -739,43 +739,19 @@ x_window_init(
 	int  create_gc	/* ignored */
 	)
 {
-	/*
-	 * these values are set later
-	 */
-
-	win->parent_window = None ;
-	win->my_window = None ;
+	memset( win , 0 , sizeof( x_window_t)) ;
 
 	win->fg_color.pixel = 0xff000000 ;
 	win->bg_color.pixel = 0xffffffff ;
 
-	win->parent = NULL ;
-	win->children = NULL ;
-	win->num_of_children = 0 ;
-
-	win->pic_mod = NULL ;
-
-	win->wall_picture = None ;
-	win->is_transparent = 0 ;
-
-	win->cursor_shape = 0 ;
-
-	win->event_mask = 0 ;
-
 	/* if visibility is partially obscured , scrollable will be 0. */
 	win->is_scrollable = 1 ;
 
-	win->is_focused = 0 ;
-
 	/* This flag will map window automatically in x_window_show(). */
 	win->is_mapped = 1 ;
 
-	win->is_sel_owner = 0 ;
-
 	win->create_gc = create_gc ;
 
-	win->x = 0 ;
-	win->y = 0 ;
 	win->width = width ;
 	win->height = height ;
 	win->min_width = min_width ;
@@ -786,48 +762,15 @@ x_window_init(
 	win->height_inc = height_inc ;
 	win->margin = margin ;
 
-	win->xim = NULL ;
-	win->xim_listener = NULL ;
-	
-	win->xic = NULL ;
-
 	/* Not freed explicitly. Expect to be freed on process exited. */
 	if( ! m_cp_parser && ( m_cp_parser = mkf_codepoint_parser_new()) == NULL)
 	{
 		return  0 ;
 	}
 
-	win->update_window_flag = 0 ;
-
-	win->prev_clicked_time = 0 ;
 	win->prev_clicked_button = -1 ;
-	win->click_num = 0 ;
-	win->button_is_pressing = 0 ;
-	win->dnd = NULL ;
-	win->app_name = __("mlterm") ;
 
-	win->window_realized = NULL ;
-	win->window_finalized = NULL ;
-	win->window_exposed = NULL ;
-	win->update_window = NULL ;
-	win->window_focused = NULL ;
-	win->window_unfocused = NULL ;
-	win->key_pressed = NULL ;
-	win->pointer_motion = NULL ;
-	win->button_motion = NULL ;
-	win->button_released = NULL ;
-	win->button_pressed = NULL ;
-	win->button_press_continued = NULL ;
-	win->window_resized = NULL ;
-	win->child_window_resized = NULL ;
-	win->selection_cleared = NULL ;
-	win->xct_selection_requested = NULL ;
-	win->utf_selection_requested = NULL ;
-	win->xct_selection_notified = NULL ;
-	win->utf_selection_notified = NULL ;
-	win->window_deleted = NULL ;
-	win->mapping_notify = NULL ;
-	win->set_xdnd_config = NULL ;
+	win->app_name = __("mlterm") ;
 
 	return	1 ;
 }
@@ -1275,8 +1218,25 @@ x_window_resize(
 		return  0 ;
 	}
 
-	win->width = width ;
-	win->height = height ;
+	/* Max width of each window is screen width. */
+	if( GetSystemMetrics( SM_CXSCREEN) < width)
+	{
+		win->width = GetSystemMetrics( SM_CXSCREEN) ;
+	}
+	else
+	{
+		win->width = width ;
+	}
+
+	/* Max height of each window is screen height. */
+	if( GetSystemMetrics( SM_CYSCREEN) < height)
+	{
+		win->height = GetSystemMetrics( SM_CYSCREEN) ;
+	}
+	else
+	{
+		win->height = height ;
+	}
 
 	if( (flag & NOTIFY_TO_PARENT) && win->parent && win->parent->child_window_resized)
 	{
@@ -1386,6 +1346,7 @@ x_window_clear(
 {
 	RECT  r ;
 
+#ifdef  AUTO_CLEAR_MARGIN
 	if( x + width >= win->width)
 	{
 		/* Clearing margin area */
@@ -1393,9 +1354,11 @@ x_window_clear(
 	}
 
 	if( x > 0)
+#endif
 	{
 		x += win->margin ;
 	}
+#ifdef  AUTO_CLEAR_MARGIN
 	else
 	{
 		/* Clearing margin area */
@@ -1409,14 +1372,17 @@ x_window_clear(
 	}
 
 	if( y > 0)
+#endif
 	{
 		y += win->margin ;
 	}
+#ifdef  AUTO_CLEAR_MARGIN
 	else
 	{
 		/* Clearing margin area */
 		height += win->margin ;
 	}
+#endif
 
 	r.left = x ;
 	r.top = y ;
@@ -1790,13 +1756,13 @@ x_window_receive_event(
 				height = ps.rcPaint.bottom - y /* + 1 */ ;
 			}
 
-			(*win->window_exposed)( win, x, y, width, height) ;
-
 			if( margin_area_exposed)
 			{
 				x_window_clear_margin_area( win) ;
 			}
 
+			(*win->window_exposed)( win, x, y, width, height) ;
+
 			EndPaint( win->my_window, &ps) ;
 			x_set_gc( win->gc, None) ;
 
@@ -1824,31 +1790,88 @@ x_window_receive_event(
 			
 			return  1 ;
 		}
-	
+
+	case WM_SYSKEYDOWN:
 	case WM_KEYDOWN:
 		if( win->key_pressed)
 		{
+			XKeyEvent  kev ;
+
 			if( ( 0x30 <= event->wparam && event->wparam <= VK_DIVIDE) ||
 				event->wparam == VK_BACK || event->wparam == VK_TAB ||
 				event->wparam == VK_RETURN || event->wparam == VK_ESCAPE ||
 				event->wparam == VK_SPACE)
 			{
-				/* wait for WM_**_CHAR message. */
+				kev.state = get_key_state() ;
+				kev.ch = event->wparam ;
+
+				if( ( kev.state & ModMask) && event->msg == WM_SYSKEYDOWN)
+				{
+					/* Alt+key (which doesn't cause WM_*_CHAR message) */
+
+					if( 'A' <= kev.ch && kev.ch <= 'Z')
+					{
+						/*
+						 * Upper case => Lower case.
+						 * event->wparam is always upper case
+						 * if alt key is pressed together.
+						 */
+						kev.ch = event->wparam + 0x20 ;
+					}
+				}
+				else if( ( kev.state & ControlMask) &&
+				         '2' <= kev.ch && kev.ch <= '8')
+				{
+					/*
+					 * - See x_xic_get_str() in x_xic_win32.c.
+					 * - Control+2-8 (which doesn't cause WM_*_CHAR message.
+					 */
+				}
+				else
+				{
+					/* wait for WM_*_CHAR message. */
+					break ;
+				}
+			}
+			else if( event->msg == WM_SYSKEYDOWN)
+			{
+				break ;
 			}
 			else
 			{
-				XKeyEvent  kev ;
-
-				kev.state = get_key_state() ;
 				kev.ch = 0 ;
 
-				(*win->key_pressed)( win, &kev) ;
+				if( ( kev.state = get_key_state()) & ControlMask)
+				{
+					/*
+					 * - See x_xic_get_str() in x_xic_win32.c.
+					 * - Following VK_* keys don't cause WM_*_CHAR message.
+					 */
+
+					/* Control+/ (106-JP Keyboard) */
+					if( event->wparam == VK_OEM_2)
+					{
+						kev.ch = '/' ;
+					}
+					/* Control+^ (106-JP Keyboard) */
+					else if( event->wparam == VK_OEM_7)
+					{
+						kev.ch = '^' ;
+					}
+					/* Control+_ (106-JP Keyboard) */
+					else if( event->wparam == VK_OEM_102)
+					{
+						kev.ch = '_' ;
+					}
+				}
 			}
+
+			(*win->key_pressed)( win , &kev) ;
 		}
 
-		/* Continued default processing. */
+		/* Continue default processing. */
 		break ;
-		
+
 	case WM_IME_CHAR:
         case WM_CHAR:
 		if( win->key_pressed)
@@ -1873,7 +1896,7 @@ x_window_receive_event(
 				kev.ch = event->wparam ;
 			}
 
-			(*win->key_pressed)( win, &kev) ;
+			(*win->key_pressed)( win , &kev) ;
 		}
 		
 		return  1 ;
@@ -2714,7 +2737,8 @@ x_window_draw_rect_frame(
 	x_release_pen( x_gc_set_pen( win->gc, x_acquire_pen( win->fg_color.pixel))) ;
 	x_release_brush( x_gc_set_brush( win->gc, GetStockObject(NULL_BRUSH))) ;
 	
-	Rectangle( win->gc->gc, x1, y1, x2, y2) ;
+	Rectangle( win->gc->gc, x1 + win->margin , y1 + win->margin ,
+			x2 + win->margin , y2 + win->margin) ;
 
 	return  1 ;
 }
